<?php
namespace App\Http\Controllers;
use App\Repositories\ConfigCityManagementRepository;
use App\Transformers\CityTransformer;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use League\Fractal\Pagination\IlluminatePaginatorAdapter;
use League\Fractal\Resource\Collection;
use League\Fractal\Manager;
use Illuminate\Validation\Rule;
/**
 * Created by PhpStorm.
 * User: qinyaer
 * Date: 2019/4/26
 * Time: 下午13:56
 */

class ConfigCityManagementController extends Controller
{
    public function __construct(ConfigCityManagementRepository $configCityManagementRepository)
    {
        $this->configCityManagementRepository = $configCityManagementRepository;
    }

    //城市列表
    public function lists(Request $request)
    {

        $cityList = $this->configCityManagementRepository->index($request->all());

        $fractal = new Manager();
        $resource = new Collection($cityList, new CityTransformer());
        $resource->setPaginator(new IlluminatePaginatorAdapter($cityList));
        $data = $fractal->createData($resource)->toArray();
        $data['extra'] = [
            'filters' => [
                'id'
            ],
            'columns' => [
                'id',
                'province_id',
                'province_name',
                'city_name',
                'city_id',
                'express_type',
                'status',
            ]
        ];
        return $data;
    }

    /**
     * 添加城市
     */
    public function create(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'province_id' => 'required',
            'province_name' => 'required|string',
            'city_id' => 'required',
            'city_name' => 'required|string',
            'express_type' => 'required',
        ]);
        if ($validator->fails()) {
            return $this->response->error($validator->errors()->first(), 500);
        }
        return  $this->configCityManagementRepository->create($request->all());
    }


    //编辑城市
    public function edit(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required|exists:config_city_management',
            'province_name' => 'required|string',
            'province_id' => 'required',
            'city_id' => 'required',
            'express_type' => 'required',
            'city_name' => 'required|string|max:30',
        ]);

        if ($validator->fails()) {

            return $this->response->error($validator->errors()->first(), 500);
        }

        return $this->configCityManagementRepository->edit($request->all());
    }

    //删除城市
    public function delete(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'id' => 'required|exists:config_city_management'
        ]);
        if ($validator->fails()) {
            return $this->response->error($validator->errors()->first(), 500);
        }
        return $this->configCityManagementRepository->delete($request->all());

    }

}